@@ -2,5 +2,5 @@ from kappadata.wrappers.sample_wrappers.multi_view_wrapper import MultiViewWrapp
 from kappadata.common.transforms.byol_transforms import BYOLTransform0, BYOLTransform1
 
 class BYOLMultiViewWrapper(MultiViewWrapper):
-    def __init__(self):
-        super().__init__(configs=[BYOLTransform0(), BYOLTransform1()])
\ No newline at end of file
+    def __init__(self, dataset):
+        super().__init__(dataset=dataset, configs=[BYOLTransform0(), BYOLTransform1()])
\ No newline at end of file
